| tl_plot_model | R Documentation |
Dispatches to the appropriate plotting function based on model type and requested plot type.
tl_plot_model(model, type = "auto", ...)
model |
A tidylearn supervised model object |
type |
Plot type. For regression: "auto", "actual_predicted", "residuals", "diagnostics". For classification: "auto", "confusion", "roc", "precision_recall", "calibration", "lift", "gain". "importance" is available for tree-based and regularized models. |
... |
Additional arguments passed to the underlying plot function |
A ggplot2 object (invisibly for base-graphics plots)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.