| tl_plot_unsupervised | R Documentation |
Dispatches to the appropriate plotting function based on the unsupervised model method.
tl_plot_unsupervised(model, type = "auto", ...)
model |
A tidylearn unsupervised model object |
type |
Plot type (default: "auto"). Currently unused; reserved for future sub-type selection. |
... |
Additional arguments passed to the underlying plot function |
A ggplot2 object or invisible result
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.