Tune a deep learning model
tl_tune_deep(
data,
formula,
is_classification = FALSE,
hidden_layers_options = list(c(32), c(64, 32), c(128, 64, 32)),
learning_rates = c(0.01, 0.001, 1e-04),
batch_sizes = c(16, 32, 64),
epochs = 30,
validation_split = 0.2,
...
)A list with the best model and tuning results
A data frame containing the training data
A formula specifying the model
Logical indicating if this is a classification problem
List of vectors defining hidden layer configurations to try
Learning rates to try (default: c(0.01, 0.001, 0.0001))
Batch sizes to try (default: c(16, 32, 64))
Number of training epochs (default: 30)
Proportion of data for validation (default: 0.2)
Additional arguments